pub struct Schema {
pub fields: Vec<FieldDef>,
}Expand description
Ordered list of field definitions for a dataset.
Fields
fields: Vec<FieldDef>Implementations
Sourceimpl Schema
impl Schema
Sourcepub fn fields_of_kind(&self, kind: FieldKind) -> impl Iterator<Item = &str>
pub fn fields_of_kind(&self, kind: FieldKind) -> impl Iterator<Item = &str>
Iterate over field names that match a given kind.
Sourcepub fn field_index(&self, name: &str) -> Option<usize>
pub fn field_index(&self, name: &str) -> Option<usize>
Return the position of a field by name, or None if absent.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool